<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>Raio inválido</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>Nenhuma solução</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Selecione uma entidade ou uma região</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Mova uma entidade ou um ponto de referência</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Defina o segundo vértice</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Indique o ponto de destino para o ponto de referência</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Indique o ponto de destino da seleção</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Mova a entidade para a localização desejada</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Mova o Ponto de Referência</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Mova a Seleção</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Mova a Entidade</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Edição bloco &apos;%1&apos;&lt;br&gt;Escolha &lt;i&gt;Bloco &gt; Retorne ao Desenho Principal&lt;/i&gt; quando feito</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Anterior
Retorna ao último menu</translatorcomment>
        <translation>Anterior</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Cancelar
&amp;Cancelar</translatorcomment>
        <translation>Cancele</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Ferramenta Ativa:</translation>
    </message>
    <message>
        <source>Active Tool: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ferramenta de ativos:</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Nenhum
nenhum
Nenhuma das entidades selecionadas pode ser dividida.</translatorcomment>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Opções de Ferramentas
Opções de Biselamento</translatorcomment>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Opções de Bloco</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ferramentas Principais</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
Ferramentas CAD</translatorcomment>
        <translation>Ferramentas CAD</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A entidade está em uma camada bloqueada.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Comprimento:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A entidade não é uma referência de Bloco.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A entidade não é uma linha ou um arco.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>A entidade não é uma linha, arco ou polilinha.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A entidade não é uma linha.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A entidade não é um arco ou círculo.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A entidade não é uma linha, arco ou círculo.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A entidade não é um arco, círculo ou elipse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>A entidade não é uma linha, arco, círculo ou elipse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>A entidade não é uma linha, arco, círculo, elipse ou polilinha.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>A entidade não é uma linha, arco, círculo, elipse ou spline.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>A entidade não é uma linha, arco, círculo, elipse, spline ou polilinha.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A entidade não é um polilinha.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">O Raio ficou abaixo de 0,0, após %1 círculo(s) concêntrico(s).</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">O Raio ficou abaixo de 0,0, após %1 arco(s) concêntrico(s).</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pelo menos dois pontos são idênticos.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nenhum círculo possível.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Nenhum arco possível.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Número de segmentos inválido: %1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Inválidas - elipse maior / menor: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translatorcomment>--ignored case--
--file: qt_pt.ts--
Restaurar os padrões do sistema ou ferramenta
Restaurar Predefinições</translatorcomment>
        <translation>Restaure padrões</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translatorcomment>--exact match--
--file: Text_pt.ts--
Insira um símbolo no rótulo
Insere símbolo
Insere Símbolo</translatorcomment>
        <translation>Insira um Símbolo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translatorcomment>--exact match--
--file: Text_pt.ts--
Comute o símbolo de diâmetro
Diâmetro (ø)</translatorcomment>
        <translation>Diâmetro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Arco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translatorcomment>--exact match--
--file: Text_pt.ts--
Graus decimais
Grau:</translatorcomment>
        <translation>Grau</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translatorcomment>--exact match--
--file: Dimension_pt.ts--
Plus / Minus</translatorcomment>
        <translation>Mais/Menos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Quase igual a</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Assintoticamente igual a</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translatorcomment>--exact match--
--file: Text_pt.ts--
Copie entidades para a área de transferência
Copie entidade com ponto de referência  para o clipboard</translatorcomment>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Raiz quadrada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>Alt phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translatorcomment>--exact match--
--file: Text_pt.ts--
Multiplicação</translatorcomment>
        <translation>Multiplicação</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translatorcomment>--exact match--
--file: pt.po--
Divisão (÷)
Divisão</translatorcomment>
        <translation>Divisão</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Quadrado</translatorcomment>
        <translation>Quadrado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translatorcomment>--exact match--
--file: Text_pt.ts--
Delta
Delta X</translatorcomment>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Texto empilhado</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Valor medido</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Alinhado</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Meio</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Ajustado para</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Base</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation>Horário</translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation>Anti-horário</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation>Acima</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <source>Loading plugins...</source>
        <translatorcomment>--exact match--
--file: qgis_pt.ts--
Carregando plugins...</translatorcomment>
        <translation type="obsolete">Carregando plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins...</source>
        <translation type="obsolete">Inicializar plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Inicializar plugins:</translation>
    </message>
    <message>
        <source>Post-initializing plugins...</source>
        <translation type="obsolete">Inicializar plugins...</translation>
    </message>
    <message>
        <source>Post-Initialization...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pós-inicialização...</translation>
    </message>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Carregando traduções da add-on...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Carregando add-ons...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Iniciando add-on...</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Pós-inicialização de add-ons...</translation>
    </message>
    <message>
        <source>Loading add-on translations ...</source>
        <translation type="obsolete">Carregar add-on traduções ...</translation>
    </message>
    <message>
        <source>Loading add-ons ...</source>
        <translation type="obsolete">Carregando add-ons ...</translation>
    </message>
    <message>
        <source>Initializing add-ons ...</source>
        <translation type="obsolete">Inicializar add-ons ...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Iniciando add-ons:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons ...</source>
        <translation type="obsolete">Pós-inicialização ...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Objectos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Objecto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Objectos Desconhecidas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Objecto Desconhecida</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Blocos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Bloco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Camadas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Camada</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>Layouts</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Tipos de Linha</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Tipo de Linha</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Vistas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Entidade</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Entidades</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Faces3d</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Face3d</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Referências de Bloco</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translatorcomment>--google--
Escolha referência de bloco
Editar bloco baseado em referência de bloco</translatorcomment>
        <translation>Referência de Bloco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Referências de Bloco e Atributos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Referências de Bloco e Atributos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translatorcomment>--google--
Desenhe arcos
Desenhe arcos com 3 pontos
Desenhe linhas paralelas a linhas, arcos ou círculos existentes</translatorcomment>
        <translation>Arcos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translatorcomment>--exact match--
--file: AdvancedSelection_pt.ts--
&amp;Arco
Arco
Selecione a primeira linha ou arco</translatorcomment>
        <translation>Arco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Atributo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Definições de Atributo</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Definição de Atributo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translatorcomment>--google--
Desenhe linhas paralelas a linhas, arcos ou círculos existentes
Desenhe círculos com centro e ponto
Desenhe círculos com 2 pontos</translatorcomment>
        <translation>Círculos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Círculo
Círculo
Não é uma entidade de círculo ou arco</translatorcomment>
        <translation>Círculo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Dimensões</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Dimensão</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dimensões Alinhadas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimension</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Dimensão Alinhada
Desenhe dimensão alinhados</translatorcomment>
        <translation>Dimensão Alinhada</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimensions</source>
        <translatorcomment>--exact match--
--file: DimensionSettings_pt.ts--
Dimensões angulares</translatorcomment>
        <translation>Dimensões Angulares</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimension</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Dimensão angular
Desenhe dimensão angular</translatorcomment>
        <translation>Dimensão Angular</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation>Dimensões angulares de 2 linhas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation>Dimensão angular de 2 linhas</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation>Dimensões angulares de 3 pontos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation>Dimensão angular de 3 pontos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation>Dimensão do arco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dimensões de Diâmetros</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimension</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Dimensão do diâmetro
Desenhe dimensão diametral</translatorcomment>
        <translation>Dimensão de Diâmetro</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dimensões de Ordenada</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimension</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Ordene dimensão
Dimenção Ordinal
Desenhe dimensão ordenada</translatorcomment>
        <translation>Dimensão de Ordenada</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dimensões Rotacionadas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dimensão Rotacionada</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dimensões Radiais</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimension</source>
        <translatorcomment>--ignored case--
--file: qcadactions_pt.ts--
Dimensão radial
Desenhe dimensão radial</translatorcomment>
        <translation>Dimensão Radial</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translatorcomment>--exact match--
--file: pt.po--
Desenha Elipses
Exibe o menu &quot;Elipse&quot;</translatorcomment>
        <translation>Elipses</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Elipse
Elipse
&amp;Arco de Elipse (Eixo)</translatorcomment>
        <translation>Elipse</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translatorcomment>--exact match--
--file: Explode_pt.ts--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos</translatorcomment>
        <translation>Hachuras</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translatorcomment>--exact match--
--file: Hatch_pt.ts--
&amp;Hachura
Hachura
Desenhe hachurados e preenchimentos sólidos</translatorcomment>
        <translation>Hachura</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Embutir imagens
Embutir somente a imagem selecionada</translatorcomment>
        <translation>Imagens</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Exporte Imagem
&amp;Imagem</translatorcomment>
        <translation>Imagem</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leaders</source>
        <translatorcomment>--google--
Chefes de projecto</translatorcomment>
        <translation>Guias</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leader</source>
        <translatorcomment>--exact match--
--file: Leader_pt.ts--
&amp;Conduza
Conduza
Conduza (seqüência linear com seta)</translatorcomment>
        <translation>Guia</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translatorcomment>--exact match--
--file: pt.po--
Desenhe linhas paralelas a linhas, arcos ou círculos existentes
Desenhe linhas</translatorcomment>
        <translation>Linhas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translatorcomment>--exact match--
--file: pt.po--
Foca na &amp;Linha de Comando
Foca na Linha de Comando
&amp;Linha</translatorcomment>
        <translation>Linha</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Linhas Infinitas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Linha Infinita</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Raios</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Raio</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;3 Pontos
3 Pontos
Desenhe arcos com 3 pontos</translatorcomment>
        <translation>Pontos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Ponto
Ponto
Indique o ponto de referência</translatorcomment>
        <translation>Ponto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenhe Multilinhas
Adicione nós a multilinhas existentes</translatorcomment>
        <translation>Polilinhas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Polilinha
&lt;b&gt;Multilinha&lt;/b&gt;
Desenhe Multilinhas</translatorcomment>
        <translation>Polilinha</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solids</source>
        <translatorcomment>--google--
em linhas, sólidos e textos</translatorcomment>
        <translation>Sólidos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solid</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos</translatorcomment>
        <translation>Sólido</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Traços</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Traço</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>Faces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>Face</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translatorcomment>--exact match--
--file: Explode_pt.ts--
Desenhe chavetas (NURBS)
Desenha chavetas</translatorcomment>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translatorcomment>--exact match--
--file: Spline_pt.ts--
&amp;Spline
Spline
Desenhe chavetas (NURBS)</translatorcomment>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Baseado em texto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translatorcomment>--exact match--
--file: pt.po--
em linhas, sólidos e textos
Remover traço
Textos</translatorcomment>
        <translation>Textos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Insira o texto de dimensão:
Insira o texto de dimensão
&amp;Texto</translatorcomment>
        <translation>Texto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Âncoras de Visão</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Âncora de Visão</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidades Desconhecidas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidade Desconhecida</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>A primeira entidade não pode ser aparada.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Entidade não pode ser aparada.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>A segunda entidade não pode ser aparada.</translation>
    </message>
</context>
</TS>
